Settings
========

Some settings are documented on other documentation pages. In addition, you can
set the following values in your settings.py to customise the behaviour of django-paypal.


.. attribute:: PAYPAL_BUY_BUTTON_IMAGE

   The URL of the image to be used for 'buy' buttons.

.. attribute:: PAYPAL_DONATE_BUTTON_IMAGE

   The  URL of the image to be used for 'donate' buttons.

.. attribute:: PAYPAL_SUBSCRIPTION_BUTTON_IMAGE

   The URL of the image to be used for 'subscription' buttons.
